%% make table 
load('NK_test1.mat')

fs=samplerate(1);

ECG=data(1:dataend(1));             %EKG
LDF=data(dataend(1)+1:dataend(2));  %laser doppler flow
BP=data(dataend(2)+1:dataend(3));   %finger preassure
sys=data(dataend(3)+1:dataend(4));  %systolic pressure
MAP=data(dataend(4)+1:dataend(5));  %mean arterial
dia=data(dataend(5)+1:dataend(6));  %diastolic
HR=data(dataend(6)+1:dataend(7));   %heart rate

L=length(ECG);

T=table(ECG,LDF,BP,sys,MAP,dia,HR);

%% HR and findpeaks
[~,locs_R]=findpeaks(ECG,'MinPeakHeight',0.5*10^-3,'MinPeakDistance',200);
figure(1)
hold on
plot(ECG)
plot(locs_R,ECG(locs_R),'rv','MarkerFaceColor','r');
hold off

for i=1:length(locs_R)-1
    HR_ecg(i)=(locs_R(i+1)-locs_R(i))/1000 * 60;
end


%% PSD
n= 4*1024; %2^nextpow2(L);
f = fs*(0:(n/2))/n;
Y=fft(ECG,n);
P1=abs(Y/n);
P2=P1(1:n/2+1);

figure(2)
semilogx(f,smooth(P2))
title('Single-Sided Amplitude Spectrum using fft of ECG(t)')
xlabel('f (Hz)')
ylabel('|P1(f)|')

figure(3)
[pxx,f]=pwelch(ECG,4000,4000/2,n,fs);
semilogx(f,pxx)
title('Welch PSD')

%% Spectogram
Nx = length(ECG); 
nsc = floor(Nx/100);
nov = floor(nsc/4);
nff = 100*  1024  %max(1024,2^nextpow2(nsc));

figure(4)
spectrogram(ECG,hamming(nsc),nov,nff,fs);

%% Wavelet

[A,D]=dwt(ECG,'db4');
[Aa,Da]=dwt(A,'db4');
[Aaa,Daa]=dwt(Aa,'db4');

t=linspace(0,5,length(A));

figure
subplot(211)
plot(t,A)
subplot(212)
plot(t,D)

taa=linspace(0,5,length(Aaa));
figure
subplot(211)
plot(taa,Aaa)
subplot(212)
plot(taa,Daa)


[c,l]=wavedec(ECG,4,'db4');

ca1=appcoef(c,l,'db4',1);
ca2=appcoef(c,l,'db4',2);
ca3=appcoef(c,l,'db4',3);
ca4=appcoef(c,l,'db4',4);

t1=linspace(0,5,length(ca1));
t2=linspace(0,5,length(ca2));
t3=linspace(0,5,length(ca3));
t4=linspace(0,5,length(ca4));

figure
subplot(221)
plot(t1,ca1)
subplot(222)
plot(t2,ca2)
subplot(223)
plot(t3,ca3)
subplot(224)
plot(t4,ca4)

%% wavlet 2
%fungerer drlig

DT=1/fs;
t = 0:DT:(numel(ECG)*DT)-DT;

cwt_ecg=cwtft(ECG);

helperCWTTimeFreqPlot(cwt_ecg.cfs,t.*1e6,cwt_ecg.frequencies./1000,...
    'surf','Bat Echolocation (CWT)','Microseconds','kHz')

%% filtering

y1 = sgolayfilt(kron(ones(1,13),ECG),0,21);

figure(5)
subplot(211)
plot(ECG)
subplot(212)
plot(y1)

