%% load
load('NK_test1.mat')

fs1=samplerate(1);
fs2=samplerate(3);


ECG=data(1:dataend(1));             %EKG
LDF=data(dataend(1)+1:dataend(2));  %laser doppler flow
BP=data(dataend(2)+1:dataend(3));   %finger preassure
sys=data(dataend(3)+1:dataend(4));  %systolic pressure
MAP=data(dataend(4)+1:dataend(5));  %mean arterial
dia=data(dataend(5)+1:dataend(6));  %diastolic
HR=data(dataend(6)+1:dataend(7));   %heart rate

L_ECG=length(ECG);
L_BP=length(BP);

range=[1 300];       %intressting area in sec [1-300]

med_plot(BP,'BP',fs2,ECG,'ECG',fs1,range)

[x_exc,t,fs,sig_name]=signal_exc(ECG,'ECG',range,fs1);


%% Wavlet decomposition

[x_w,t_w,fs_w,lvl]=wavedecom(x_exc,t,fs,4,'db4');


figure
subplot(211)
plot(t,x_exc), grid
legend('original')
title('Wavlet decomp')
axis('tight')
subplot(212)
plot(t_w,x_w), grid
legend(['reconstructed at level: ' num2str(lvl)])
axis('tight')

nfft=10*1024;
f_w = fs_w*(0:(nfft/2))/nfft;
x_w_fft=fft(x_w,nfft);
P_x=abs(x_w_fft(1:nfft/2+1)/nfft);

figure
semilogx(f_w,smooth(P_x,5))
title('FFT of wavelet rec signal')
axis('tight')
axis([0 2 0 1e-4])



%% Matched filter 
ECG_comp=(89800:90400);      % endre til null i hver ende
                             % og bruke filter fra filtrert signal som skal
                             % matches med

b = flip(ECG_comp);
%freqz(b)
%delay=length(b);
%delay=mean(grpdelay(b));
delay_m=(length(b)-1)/2;        % m prve  endre delay
m=filter(b,1,x_exc_f');

matched_ECG=[m(delay_m+1:end) m(1:ceil(delay_m))];

figure
subplot(211)
plot(t,x_exc_f'), grid
legend('Original')
title('Matched filtering ECG')
subplot(212)
plot(t,matched_ECG), grid
legend('Matched')
xlabel('T [sec]')

%% filtering
%removing trend
opol = 6;
[p,s,mu] = polyfit(t,x_exc,opol);
f_y = polyval(p,t,[],mu);


x_exc_f = x_exc - f_y + mean(f_y);

figure
subplot(2,1,1)
plot(t,x_exc), grid
title( 'Detrended ECG Signals')
subplot(2,1,2)
plot(t,x_exc_f), grid
xlabel('T [sec]')

% Design lowpass filter
Fpass  = 20;
Fstop = 30;
Dpass = 0.05;
Dstop = 0.0001;
F     = [0 Fpass Fstop fs/2]/(fs/2);
A     = [1 1     0     0];
D     = [Dpass Dstop];
b = firgr('minorder', F, A, D);

delay=(length(b)-1)/2;

%freqz(b,1,1024)

f_x=filter(b,1,x_exc_f);
f_x=smooth(f_x,30); %moving average

x_exc_f= [f_x(ceil(delay)+1:end); f_x(1:ceil(delay))];

figure
subplot(211)
plot(t,x_exc), grid
title(['Filtered ',sig_name])
axis('tight')
subplot(212)
plot(t,x_exc_f), grid
axis('tight')
xlabel('T [sec]')

%% HR and findpeaks
[~,locs_R]=findpeaks(x_w,'MinPeakHeight',0.5*10^-3,'MinPeakDistance',20);
figure
hold on
plot(x_w)
plot(locs_R,x_w(locs_R),'rv','MarkerFaceColor','r');
hold off

for i=1:length(locs_R)-1
    RR(i)=(locs_R(i+1)-locs_R(i));
end

HR_ecg=RR/1000*60;
%% time-freq analysis using wavlet

cwt_x=cwtAnalysis(x_w,t_w,fs_w,sig_name);

%% FFT
n=100*1024;
f = fs*(0:(n/2))/n;
x_fft=fft(x_exc_f,n);


P1=abs(x_fft/n);
P2=P1(1:n/2+1);

p = unwrap(angle(x_fft(1:n/2+1)));

figure
subplot(211)
semilogx(f,P2)
title(['fft ', sig_name])
subplot(212)
plot(f,p)













