%% load
load('NK_test1.mat')

fs1=samplerate(1);
fs2=samplerate(3);


ECG=data(1:dataend(1));             %EKG
LDF=data(dataend(1)+1:dataend(2));  %laser doppler flow
BP=data(dataend(2)+1:dataend(3));   %finger preassure
sys=data(dataend(3)+1:dataend(4));  %systolic pressure
MAP=data(dataend(4)+1:dataend(5));  %mean arterial
dia=data(dataend(5)+1:dataend(6));  %diastolic
HR=data(dataend(6)+1:dataend(7));   %heart rate

L_ECG=length(ECG);
L_BP=length(BP);

t1=0:1/fs1:L_ECG/fs1-1/fs1;
t2=0:1/fs2:L_BP/fs2-1/fs2;

[ECG_w,t1_w,fs1_w,lvl1]=wavedecom(ECG,t1,fs1,4,'db4');
[BP_w,t2_w,fs2_w,lvl2]=wavedecom(BP,t2,fs2,2,'db4');
BP_mean=mean(BP);
BP_w_mean=mean(BP_w);
BP_w=BP_w-BP_w_mean+BP_mean;

%% plot
figure(1)
subplot(211)
plot(t1,ECG), grid
legend('original')
title('Wavlet decomp')
axis('tight')
subplot(212)
plot(t1_w,ECG_w), grid
legend(['reconstructed at level: ' num2str(lvl1)])
axis('tight')

figure(2)
subplot(211)
plot(t2,BP), grid
legend('original')
title('Wavlet decomp')
axis('tight')
subplot(212)
plot(t2_w,BP_w), grid
legend(['reconstructed at level: ' num2str(lvl2)])
axis('tight')

%% fft
nfft1=50*1024;
f1_w = fs1_w*(0:(nfft1/2))/nfft1;
ECG_w_fft=fft(ECG_w,nfft1);
P_ECG=abs(ECG_w_fft(1:nfft1/2+1)/nfft1);

figure(3)
semilogx(f1_w,smooth(P_ECG,3))
title('FFT of ECG wavelet rec signal')
%axis('tight')
axis([0 2 0 1e-4])

nfft2=40*1024;
f2_w = fs2_w*(0:(nfft2/2))/nfft2;
BP_w_fft=fft(BP_w,nfft2);
P_BP=abs(BP_w_fft(1:nfft2/2+1)/nfft2);

figure(4)
semilogx(f2_w,smooth(P_BP,3))
title('FFT of BP wavelet rec signal')
%axis('tight')
axis([0 2 0 5])

%% wavlet analysis

cwt_ECG=cwtAnalysis(ECG_w,t1_w,fs1_w,'ECG',5,6);

cwt_BP=cwtAnalysis(BP_w,t2_w,fs2_w,'BP',7,8);

